<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Database\Query\SelectInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\State\StateInterface;
use Drupal\migrate\Plugin\migrate\source\SqlBase;
use Drupal\migrate\Plugin\MigrationInterface;
use Drupal\migrate_wizard\Plugin\migrate\source\Wildcard;
use Drupal\mysql\Driver\Database\mysql\Select;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for FieldType plugins.
 */
abstract class FieldTypeMWBase {

  public static function getMWDatabase($mw_database) {
    return \Drupal::service('entity_type.manager')->getStorage('mw_database')->load($mw_database);
  }

  /**
   * {@inheritdoc}
   */
  public static function insertBeforeKey($originalArray, $originalKey, $insertKey, $insertValue) {

    $newArray = [];
    $inserted = FALSE;
    foreach ($originalArray as $key => $value) {
      if (!$inserted && $key === $originalKey) {
        if(!isset($newArray[$insertKey])){
          $newArray[$insertKey] = [$insertValue];
        }else{
          $newArray[$insertKey][] = $insertValue;
        }
        $inserted = TRUE;
      }
      $newArray[$key] = $value;
    }
    return $newArray;
  }
}
