<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'generic_reference' field type.
 *
 * @FieldType(
 *   id = "generic_reference",
 * )
 */
class FieldTypeMWGenericReference extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {

    switch($data_field['type']){
      case 'taxonomy_term_reference':
        $source = 'tid';
        break;
      case 'node_reference':
        $source = 'nid';
        break;
      default:
        $source = 'target_id';
        break;
    }

    $array_config[$data_field['destiny']][] = [
      'plugin' => 'skip_on_empty',
      'source' => $origin_field,
      'method' => 'process',
    ];

    if ($source !== 'target_id') {
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'method' => 'process',
        'process' => [
          'target_id' => [
            'plugin' => 'migration_lookup',
            'source' => $source,
            'migration' => $data_field["migration_lookup"],
            'no_stub' => TRUE,
          ]
        ],
      ];
    }
    else {
      foreach($data_field["migration_lookup"] as $bundle){
        $array_config[$data_field['destiny']][] = [
          'plugin' => 'migration_lookup',
          'migration' => $bundle,
          'no_stub' => true,
        ];
      }
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'process' => [$source => '0', 'target_revision_id' => '1'],
      ];
    }


    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);

    foreach ($data_field['dependencies'] as $dependency) {
      if (!in_array($dependency, $wildcard_yml_config['migration_dependencies']['required']) && $dependency != $wildcard_yml_config['id']) {
        $wildcard_yml_config['migration_dependencies']['required'][] = $dependency;
      }
    }
  }
}
