<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\field\Entity\FieldStorageConfig;
use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'link_field' field type.
 *
 * @FieldType(
 *   id = "link_field",
 * )
 */
class FieldTypeMWLinkField extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {

    $array_config = [];
    if ($data_field["destiny"] == 'social_media_links') {
      if (!isset($wildcard_yml_config['process']['pseudo_' . $data_field['destiny']])) {
        $array_config['pseudo_' . $origin_field][] = [
          'plugin' => 'skip_on_empty',
          'source' => $origin_field,
          'method' => 'process',
        ];
        $array_config['pseudo_' . $origin_field][] = [
          'plugin' => 'social_media_links',
        ];
        $array_config['pseudo_' . $data_field['destiny']][] = [
          'plugin' => 'skip_on_empty',
          'source' => ['@pseudo_' . $origin_field],
          'method' => 'process',
        ];
        $array_config['pseudo_' . $data_field['destiny']][] = [
          'plugin' => 'reset_arrays',
        ];
        $array_config[$data_field['destiny']][] = [
          'plugin' => 'skip_on_empty',
          'source' => '@pseudo_' . $data_field['destiny'],
          'method' => 'process',
        ];
        $array_config[$data_field['destiny']][] = [
          'plugin' => 'sub_process',
          'method' => 'process',
          'process' => ['link' => 'link', 'social' => 'social'],
        ];
      }
      else {
        $insert_value = [
          'plugin' => 'skip_on_empty',
          'source' => $origin_field,
          'method' => 'process',
        ];
        $wildcard_yml_config['process'] = parent::insertBeforeKey($wildcard_yml_config['process'], 'pseudo_' . $data_field['destiny'], 'pseudo_' . $origin_field, $insert_value);
        $wildcard_yml_config['process']['pseudo_' . $origin_field][] = [
          'plugin' => 'social_media_links',
        ];
        $wildcard_yml_config['process']['pseudo_' . $data_field['destiny']][0]['source'][] = '@pseudo_' . $origin_field;
      }
    }
    else {
      // @todo unserialize attributes d7, map to d10 and serialize
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'skip_on_empty',
        'source' => $origin_field,
        'method' => 'process',
      ];
      $array_config[$data_field['destiny']][] = [
        'plugin' => 'sub_process',
        'process' => [
          'uri' => 'url',
          'title' => 'title',
        ]
      ];
    }
    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
  }
}
