<?php
/**
 * @file
 * Handles the automatic generation of migration YAML files.
 *
 * Migrate Wizard - Facilitates migration from Drupal 7 by mapping fields and content types
 * through an interface, without the need for programming.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Migrate Wizard. If not, see <https://www.gnu.org/licenses/>.
 *
 * Author: Carlos Romero Álvarez
 */

namespace Drupal\migrate_wizard\Plugin\FieldTypeMW;

use Drupal\migrate_wizard\FieldTypeMWBase;

/**
 * Provides 'paragraphs' field type.
 *
 * @FieldType(
 *   id = "paragraphs",
 * )
 */
class FieldTypeMWParagraphs extends FieldTypeMWBase {

  public static function getD7MigrationConfig(&$wildcard_yml_config, $origin_field, $data_field, $type_source, $config, $entityFieldManager, $fieldTypeMWManager, $langcode = NULL): void {

    $mw_database = parent::getMWDatabase($wildcard_yml_config["source"]["mw_database"]);
    $suffix = '';
    if(isset($wildcard_yml_config["source"]["constants"]["translations"]) && $wildcard_yml_config["source"]["constants"]["translations"]){
      $suffix = '_'.$langcode;
    }
    $destiny_explode = explode('/', $data_field['destiny']);
    $array_config[$destiny_explode[0]][] = [
      'plugin' => 'skip_on_empty',
      'method' => 'process',
      'source' => $origin_field,
    ];

    foreach($data_field["bundle"] as $bundle){
      $array_config[$destiny_explode[0]][] = [
        'plugin' => 'migration_lookup',
        'migration' => $bundle.'_'.$mw_database->id.$suffix,
        'no_stub' => true,
      ];
    $wildcard_yml_config['migration_dependencies']['required'][] = $bundle.'_'.$mw_database->id;
    }
    $array_config[$destiny_explode[0]][] = [
      'plugin' => 'sub_process',
      'process' => ['target_id' => '0', 'target_revision_id' => '1'],
    ];

    $wildcard_yml_config['process'] = array_merge($wildcard_yml_config['process'], $array_config);
  }
}
